@@ -184,6 +184,10 @@ class Hook
      */
     protected static function hasPermission($class)
     {
+        if (Icinga::app()->isCli()) {
+            return true;
+        }
+
         return Auth::getInstance()->hasPermission(
             Manager::MODULE_PERMISSION_NS . self::extractModuleName($class)
         );
@@ -259,7 +263,7 @@ class Hook
         }
 
         foreach (self::$hooks[$name] as $key => $hook) {
-            if (self::hasPermission($key)) {
+            if (self::hasPermission($hook)) {
                 if (self::createInstance($name, $key) === null) {
                     return array();
                 }
@@ -282,7 +286,7 @@ class Hook
 
         if (self::has($name)) {
             foreach (self::$hooks[$name] as $key => $hook) {
-                if (self::hasPermission($key)) {
+                if (self::hasPermission($hook)) {
                     return self::createInstance($name, $key);
                 }
             }
@@ -305,6 +309,8 @@ class Hook
             self::$hooks[$name] = array();
         }
 
+        $class = ltrim($class, ClassLoader::NAMESPACE_SEPARATOR);
+
         self::$hooks[$name][$key] = $class;
     }
 }
