@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Application\Modules;
 
@@ -120,7 +120,7 @@ class Manager
         }
         if (! is_readable($parent)) {
             throw new NotReadableError(
-                'Cannot read enabled modules. Module directory\'s parent directory "%s" is not readable',
+                'Cannot read enabled modules. Config directory "%s" is not readable',
                 $parent
             );
         }
@@ -249,6 +249,15 @@ class Manager
             );
         }
 
+        if (strtolower(substr($name, 0, 18)) === 'icingaweb2-module-') {
+            throw new ConfigurationError(
+                'Cannot enable module "%s": Directory name does not match the module\'s name.'
+                . ' Please rename the module to "%s" before enabling.',
+                $name,
+                substr($name, 18)
+            );
+        }
+
         clearstatcache(true);
         $target = $this->installedBaseDirs[$name];
         $link = $this->enableDir . DIRECTORY_SEPARATOR . $name;
