@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Data\Db;
 
@@ -9,8 +9,8 @@ use Icinga\Data\Inspection;
 use PDO;
 use Iterator;
 use Zend_Db;
+use Zend_Db_Expr;
 use Icinga\Data\ConfigObject;
-use Icinga\Data\Db\DbQuery;
 use Icinga\Data\Extensible;
 use Icinga\Data\Filter\Filter;
 use Icinga\Data\Filter\FilterAnd;
@@ -143,6 +143,24 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                 break;
             case 'mysql':
                 $adapter = 'Pdo_Mysql';
+                if ($this->config->use_ssl) {
+                    # The presence of these keys as empty strings or null cause non-ssl connections to fail
+                    if ($this->config->ssl_key) {
+                        $adapterParamaters['driver_options'][PDO::MYSQL_ATTR_SSL_KEY] = $this->config->ssl_key;
+                    }
+                    if ($this->config->ssl_cert) {
+                        $adapterParamaters['driver_options'][PDO::MYSQL_ATTR_SSL_CERT] = $this->config->ssl_cert;
+                    }
+                    if ($this->config->ssl_ca) {
+                        $adapterParamaters['driver_options'][PDO::MYSQL_ATTR_SSL_CA] = $this->config->ssl_ca;
+                    }
+                    if ($this->config->ssl_capath) {
+                        $adapterParamaters['driver_options'][PDO::MYSQL_ATTR_SSL_CAPATH] = $this->config->ssl_capath;
+                    }
+                    if ($this->config->ssl_cipher) {
+                        $adapterParamaters['driver_options'][PDO::MYSQL_ATTR_SSL_CIPHER] = $this->config->ssl_cipher;
+                    }
+                }
                 /*
                  * Set MySQL server SQL modes to behave as closely as possible to Oracle and PostgreSQL. Note that the
                  * ONLY_FULL_GROUP_BY mode is left on purpose because MySQL requires you to specify all non-aggregate
@@ -152,7 +170,13 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                  */
                 $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] =
                     'SET SESSION SQL_MODE=\'STRICT_ALL_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO,'
-                    . 'NO_AUTO_CREATE_USER,ANSI_QUOTES,PIPES_AS_CONCAT,NO_ENGINE_SUBSTITUTION\';';
+                    . 'NO_AUTO_CREATE_USER,ANSI_QUOTES,PIPES_AS_CONCAT,NO_ENGINE_SUBSTITUTION\'';
+                if (isset($adapterParamaters['charset'])) {
+                    $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .= ', NAMES ' . $adapterParamaters['charset'];
+                    unset($adapterParamaters['charset']);
+                }
+                $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .=';';
+
                 $adapterParamaters['port'] = $this->config->get('port', 3306);
                 break;
             case 'oci':
@@ -434,15 +458,42 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
         $sign = $filter->getSign();
         $value = $filter->getExpression();
 
-        if (is_array($value) && $sign === '=') {
-            // TODO: Should we support this? Doesn't work for blub*
-            return $column . ' IN (' . $this->dbAdapter->quote($value) . ')';
+        if (is_array($value)) {
+            if ($sign === '=') {
+                return $column . ' IN (' . $this->dbAdapter->quote($value) . ')';
+            } elseif ($sign === '!=') {
+                return sprintf('(%1$s NOT IN (%2$s) OR %1$s IS NULL)', $column, $this->dbAdapter->quote($value));
+            }
+
+            throw new ProgrammingError(
+                'Unable to render array expressions with operators other than equal or not equal'
+            );
         } elseif ($sign === '=' && strpos($value, '*') !== false) {
+            if ($value === '*') {
+                // We'll ignore such filters as it prevents index usage and because "*" means anything, so whether we're
+                // using a real column with a valid comparison here or just an expression which can only be evaluated to
+                // true makes no difference, except for performance reasons...
+                return new Zend_Db_Expr('TRUE');
+            }
+
             return $column . ' LIKE ' . $this->dbAdapter->quote(preg_replace('~\*~', '%', $value));
         } elseif ($sign === '!=' && strpos($value, '*') !== false) {
-            return $column . ' NOT LIKE ' . $this->dbAdapter->quote(preg_replace('~\*~', '%', $value));
+            if ($value === '*') {
+                // We'll ignore such filters as it prevents index usage and because "*" means nothing, so whether we're
+                // using a real column with a valid comparison here or just an expression which cannot be evaluated to
+                // true makes no difference, except for performance reasons...
+                return new Zend_Db_Expr('FALSE');
+            }
+
+            return sprintf(
+                '(%1$s NOT LIKE %2$s OR %1$s IS NULL)',
+                $column,
+                $this->dbAdapter->quote(preg_replace('~\*~', '%', $value))
+            );
+        } elseif ($sign === '!=') {
+            return sprintf('(%1$s != %2$s OR %1$s IS NULL)', $column, $this->dbAdapter->quote($value));
         } else {
-            return $column . ' ' . $sign . ' ' . $this->dbAdapter->quote($value);
+            return sprintf('%s %s %s', $column, $sign, $this->dbAdapter->quote($value));
         }
     }
 
@@ -463,11 +514,24 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                 case 'mysql':
                     $rows = $this->dbAdapter->query(
                         'SHOW VARIABLES WHERE variable_name ' .
-                        'IN (\'version\', \'protocol_version\', \'version_compile_os\');'
+                        'IN (\'version\', \'protocol_version\', \'version_compile_os\', \'have_ssl\');'
                     )->fetchAll();
                     $sqlinsp = new Inspection('MySQL');
+                    $hasSsl = false;
                     foreach ($rows as $row) {
                         $sqlinsp->write($row->variable_name . ': ' . $row->value);
+                        if ($row->variable_name === 'have_ssl' && $row->value === 'YES') {
+                            $hasSsl = true;
+                        }
+                    }
+                    if ($hasSsl) {
+                        $ssl_rows = $this->dbAdapter->query(
+                            'SHOW STATUS WHERE variable_name ' .
+                            'IN (\'Ssl_Cipher\');'
+                        )->fetchAll();
+                        foreach ($ssl_rows as $ssl_row) {
+                            $sqlinsp->write($ssl_row->variable_name . ': ' . $ssl_row->value);
+                        }
                     }
                     $insp->write($sqlinsp);
                     break;
