@@ -90,6 +90,13 @@ abstract class Repository implements Selectable
      */
     protected $blacklistedQueryColumns;
 
+    /**
+     * Whether the blacklisted query columns are in the legacy format
+     *
+     * @var bool
+     */
+    protected $legacyBlacklistedQueryColumns;
+
     /**
      * The filter columns being provided
      *
@@ -105,6 +112,13 @@ abstract class Repository implements Selectable
      */
     protected $filterColumns;
 
+    /**
+     * Whether the provided filter columns are in the legacy format
+     *
+     * @var bool
+     */
+    protected $legacyFilterColumns;
+
     /**
      * The search columns (or aliases) being provided
      *
@@ -112,6 +126,13 @@ abstract class Repository implements Selectable
      */
     protected $searchColumns;
 
+    /**
+     * Whether the provided search columns are in the legacy format
+     *
+     * @var bool
+     */
+    protected $legacySearchColumns;
+
     /**
      * The sort rules to be applied on a query
      *
@@ -140,6 +161,13 @@ abstract class Repository implements Selectable
      */
     protected $sortRules;
 
+    /**
+     * Whether the provided sort rules are in the legacy format
+     *
+     * @var bool
+     */
+    protected $legacySortRules;
+
     /**
      * The value conversion rules to apply on a query or statement
      *
@@ -186,9 +214,10 @@ abstract class Repository implements Selectable
     /**
      * Create a new repository object
      *
-     * @param   Selectable  $ds     The datasource to use
+     * @param   Selectable|null $ds The datasource to use.
+     *                              Only pass null if you have overridden {@link getDataSource()}!
      */
-    public function __construct(Selectable $ds)
+    public function __construct(Selectable $ds = null)
     {
         $this->ds = $ds;
         $this->aliasTableMap = array();
@@ -235,12 +264,23 @@ abstract class Repository implements Selectable
     }
 
     /**
-     * Return the datasource being used
+     * Return the datasource being used for the given table
+     *
+     * @param   string  $table
      *
      * @return  Selectable
+     *
+     * @throws  ProgrammingError    In case no datasource is available
      */
-    public function getDataSource()
+    public function getDataSource($table = null)
     {
+        if ($this->ds === null) {
+            throw new ProgrammingError(
+                'No data source available. It is required to either pass it'
+                . ' at initialization time or by overriding this method.'
+            );
+        }
+
         return $this->ds;
     }
 
@@ -323,25 +363,45 @@ abstract class Repository implements Selectable
      *
      * Calls $this->initializeBlacklistedQueryColumns() in case $this->blacklistedQueryColumns is null.
      *
+     * @param   string  $table
+     *
      * @return  array
      */
-    public function getBlacklistedQueryColumns()
+    public function getBlacklistedQueryColumns($table = null)
     {
         if ($this->blacklistedQueryColumns === null) {
-            $this->blacklistedQueryColumns = $this->initializeBlacklistedQueryColumns();
+            $this->legacyBlacklistedQueryColumns = false;
+
+            $blacklistedQueryColumns = $this->initializeBlacklistedQueryColumns($table);
+            if (is_int(key($blacklistedQueryColumns))) {
+                $this->blacklistedQueryColumns[$table] = $blacklistedQueryColumns;
+            } else {
+                $this->blacklistedQueryColumns = $blacklistedQueryColumns;
+            }
+        } elseif ($this->legacyBlacklistedQueryColumns === null) {
+            $this->legacyBlacklistedQueryColumns = is_int(key($this->blacklistedQueryColumns));
         }
 
-        return $this->blacklistedQueryColumns;
+        if ($this->legacyBlacklistedQueryColumns) {
+            return $this->blacklistedQueryColumns;
+        } elseif (! isset($this->blacklistedQueryColumns[$table])) {
+            $this->blacklistedQueryColumns[$table] = $this->initializeBlacklistedQueryColumns($table);
+        }
+
+        return $this->blacklistedQueryColumns[$table];
     }
 
     /**
-     * Overwrite this in your repository implementation in case you
-     * need to initialize the blacklisted query columns lazily
+     * Overwrite this in your repository implementation in case you need to initialize the
+     * blacklisted query columns lazily or dependent on a query's current base table
+     *
+     * @param   string  $table
      *
      * @return  array
      */
     protected function initializeBlacklistedQueryColumns()
     {
+        // $table is not part of the signature due to PHP strict standards
         return array();
     }
 
@@ -350,24 +410,47 @@ abstract class Repository implements Selectable
      *
      * Calls $this->initializeFilterColumns() in case $this->filterColumns is null.
      *
+     * @param   string  $table
+     *
      * @return  array
      */
-    public function getFilterColumns()
+    public function getFilterColumns($table = null)
     {
         if ($this->filterColumns === null) {
-            $this->filterColumns = $this->initializeFilterColumns();
+            $this->legacyFilterColumns = false;
+
+            $filterColumns = $this->initializeFilterColumns($table);
+            $foundTables = array_intersect_key($this->getQueryColumns(), $filterColumns);
+            if (empty($foundTables)) {
+                $this->filterColumns[$table] = $filterColumns;
+            } else {
+                $this->filterColumns = $filterColumns;
+            }
+        } elseif ($this->legacyFilterColumns === null) {
+            $foundTables = array_intersect_key($this->getQueryColumns(), $this->filterColumns);
+            $this->legacyFilterColumns = empty($foundTables);
         }
 
-        return $this->filterColumns;
+        if ($this->legacyFilterColumns) {
+            return $this->filterColumns;
+        } elseif (! isset($this->filterColumns[$table])) {
+            $this->filterColumns[$table] = $this->initializeFilterColumns($table);
+        }
+
+        return $this->filterColumns[$table];
     }
 
     /**
-     * Overwrite this in your repository implementation in case you need to initialize the filter columns lazily
+     * Overwrite this in your repository implementation in case you need to initialize
+     * the filter columns lazily or dependent on a query's current base table
+     *
+     * @param   string  $table
      *
      * @return  array
      */
     protected function initializeFilterColumns()
     {
+        // $table is not part of the signature due to PHP strict standards
         return array();
     }
 
@@ -376,24 +459,45 @@ abstract class Repository implements Selectable
      *
      * Calls $this->initializeSearchColumns() in case $this->searchColumns is null.
      *
+     * @param   string  $table
+     *
      * @return  array
      */
-    public function getSearchColumns()
+    public function getSearchColumns($table = null)
     {
         if ($this->searchColumns === null) {
-            $this->searchColumns = $this->initializeSearchColumns();
+            $this->legacySearchColumns = false;
+
+            $searchColumns = $this->initializeSearchColumns($table);
+            if (is_int(key($searchColumns))) {
+                $this->searchColumns[$table] = $searchColumns;
+            } else {
+                $this->searchColumns = $searchColumns;
+            }
+        } elseif ($this->legacySearchColumns === null) {
+            $this->legacySearchColumns = is_int(key($this->searchColumns));
         }
 
-        return $this->searchColumns;
+        if ($this->legacySearchColumns) {
+            return $this->searchColumns;
+        } elseif (! isset($this->searchColumns[$table])) {
+            $this->searchColumns[$table] = $this->initializeSearchColumns($table);
+        }
+
+        return $this->searchColumns[$table];
     }
 
     /**
-     * Overwrite this in your repository implementation in case you need to initialize the search columns lazily
+     * Overwrite this in your repository implementation in case you need to initialize
+     * the search columns lazily or dependent on a query's current base table
+     *
+     * @param   string  $table
      *
      * @return  array
      */
     protected function initializeSearchColumns()
     {
+        // $table is not part of the signature due to PHP strict standards
         return array();
     }
 
@@ -402,24 +506,47 @@ abstract class Repository implements Selectable
      *
      * Calls $this->initializeSortRules() in case $this->sortRules is null.
      *
+     * @param   string  $table
+     *
      * @return  array
      */
-    public function getSortRules()
+    public function getSortRules($table = null)
     {
         if ($this->sortRules === null) {
-            $this->sortRules = $this->initializeSortRules();
+            $this->legacySortRules = false;
+
+            $sortRules = $this->initializeSortRules($table);
+            $foundTables = array_intersect_key($this->getQueryColumns(), $sortRules);
+            if (empty($foundTables)) {
+                $this->sortRules[$table] = $sortRules;
+            } else {
+                $this->sortRules = $sortRules;
+            }
+        } elseif ($this->legacySortRules === null) {
+            $foundTables = array_intersect_key($this->getQueryColumns(), $this->sortRules);
+            $this->legacyFilterColumns = empty($foundTables);
         }
 
-        return $this->sortRules;
+        if ($this->legacySortRules) {
+            return $this->sortRules;
+        } elseif (! isset($this->sortRules[$table])) {
+            $this->sortRules[$table] = $this->initializeSortRules($table);
+        }
+
+        return $this->sortRules[$table];
     }
 
     /**
-     * Overwrite this in your repository implementation in case you need to initialize the sort rules lazily
+     * Overwrite this in your repository implementation in case you need to initialize
+     * the sort rules lazily or dependent on a query's current base table
+     *
+     * @param   string  $table
      *
      * @return  array
      */
     protected function initializeSortRules()
     {
+        // $table is not part of the signature due to PHP strict standards
         return array();
     }
 
@@ -900,7 +1027,7 @@ abstract class Repository implements Selectable
             throw new ProgrammingError('Table name "%s" not found', $table);
         }
 
-        $blacklist = $this->getBlacklistedQueryColumns();
+        $blacklist = $this->getBlacklistedQueryColumns($table);
         $columns = array();
         foreach ($queryColumns[$table] as $alias => $column) {
             $name = is_string($alias) ? $alias : $column;
@@ -994,7 +1121,7 @@ abstract class Repository implements Selectable
             return false;
         }
 
-        return !in_array($alias, $this->getBlacklistedQueryColumns())
+        return !in_array($alias, $this->getBlacklistedQueryColumns($table))
             && $this->validateQueryColumnAssociation($table, $name);
     }
 
@@ -1019,7 +1146,7 @@ abstract class Repository implements Selectable
             throw new QueryException(t('Query column "%s" not found'), $name);
         }
 
-        if (in_array($alias, $this->getBlacklistedQueryColumns())) {
+        if (in_array($alias, $this->getBlacklistedQueryColumns($table))) {
             throw new QueryException(t('Column "%s" cannot be queried'), $name);
         }
 
@@ -1107,7 +1234,7 @@ abstract class Repository implements Selectable
             throw new StatementException('Statement column "%s" not found', $name);
         }
 
-        if (in_array($alias, $this->getBlacklistedQueryColumns())) {
+        if (in_array($alias, $this->getBlacklistedQueryColumns($table))) {
             throw new StatementException('Column "%s" cannot be referenced in a statement', $name);
         }
 
