@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Web\Controller;
 
@@ -99,6 +99,8 @@ class ActionController extends Zend_Controller_Action
         Zend_Controller_Response_Abstract $response,
         array $invokeArgs = array()
     ) {
+        /** @var \Icinga\Web\Request $request */
+        /** @var \Icinga\Web\Response $response */
         $this->params = UrlParams::fromQueryString();
 
         $this->setRequest($request)
@@ -124,7 +126,11 @@ class ActionController extends Zend_Controller_Action
             $this->_helper->layout()->disableLayout();
         }
 
+        // $auth->authenticate($request, $response, $this->requiresLogin());
         if ($this->requiresLogin()) {
+            if (! $request->isXmlHttpRequest() && $request->isApiRequest()) {
+                Auth::getInstance()->challengeHttp();
+            }
             $this->redirectToLogin(Url::fromRequest());
         }
 
@@ -179,7 +185,7 @@ class ActionController extends Zend_Controller_Action
      */
     public function assertPermission($permission)
     {
-        if ($this->requiresAuthentication && ! $this->Auth()->hasPermission($permission)) {
+        if (! $this->Auth()->hasPermission($permission)) {
             throw new SecurityException('No permission for %s', $permission);
         }
     }
@@ -255,8 +261,9 @@ class ActionController extends Zend_Controller_Action
     /**
      * Return restriction information for an eventually authenticated user
      *
-     * @param  string  $name Permission name
-     * @return Array
+     * @param   string  $name   Restriction name
+     *
+     * @return  array
      */
     public function getRestrictions($name)
     {
@@ -268,15 +275,14 @@ class ActionController extends Zend_Controller_Action
      * user is currently not authenticated
      *
      * @return  bool
-     * @see     requiresAuthentication
      */
     protected function requiresLogin()
     {
-        if (!$this->requiresAuthentication) {
+        if (! $this->requiresAuthentication) {
             return false;
         }
 
-        return !$this->Auth()->isAuthenticated();
+        return ! $this->Auth()->isAuthenticated();
     }
 
     /**
@@ -459,15 +465,13 @@ class ActionController extends Zend_Controller_Action
         $layout->innerLayout = $this->innerLayout;
 
         if ($user = $req->getUser()) {
-            // Cast preference app.show_benchmark to bool because preferences loaded from a preferences storage are
-            // always strings
-            if ((bool) $user->getPreferences()->getValue('icingaweb', 'show_benchmark', false) === true) {
-                if (!$this->_helper->viewRenderer->getNoRender()) {
+            if ((bool) $user->getPreferences()->getValue('icingaweb', 'show_benchmark', false)) {
+                if ($this->_helper->layout()->isEnabled()) {
                     $layout->benchmark = $this->renderBenchmark();
                 }
             }
 
-            if ((bool) $user->getPreferences()->getValue('icingaweb', 'auto_refresh', true) === false) {
+            if (! (bool) $user->getPreferences()->getValue('icingaweb', 'auto_refresh', true)) {
                 $this->disableAutoRefresh();
             }
         }
