@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Web\Navigation;
 
@@ -17,6 +17,8 @@ class DashboardPane extends NavigationItem
      */
     protected $dashlets;
 
+    protected $disabled;
+
     /**
      * Set this pane's dashlets
      *
@@ -72,4 +74,24 @@ class DashboardPane extends NavigationItem
             $item->getDashlets(false)
         ));
     }
+
+    /**
+     * Set disabled state for pane
+     *
+     * @param bool $disabled
+     */
+    public function setDisabled($disabled=true)
+    {
+        $this->disabled = (bool) $disabled;
+    }
+
+    /**
+     * Get disabled state for pane
+     *
+     * @return bool
+     */
+    public function getDisabled()
+    {
+        return $this->disabled;
+    }
 }
