@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Web\Widget;
 
@@ -55,6 +55,13 @@ class FilterEditor extends AbstractWidget
      */
     private $selectedIdx;
 
+    /**
+     * Whether the filter control is visible
+     *
+     * @var bool
+     */
+    protected $visible = true;
+
     /**
      * Create a new FilterWidget
      *
@@ -144,6 +151,30 @@ class FilterEditor extends AbstractWidget
         return $this;
     }
 
+    /**
+     * Get whether the filter control is visible
+     *
+     * @return  bool
+     */
+    public function isVisible()
+    {
+        return $this->visible;
+    }
+
+    /**
+     * Set whether the filter control is visible
+     *
+     * @param   bool    $visible
+     *
+     * @return  $this
+     */
+    public function setVisible($visible)
+    {
+        $this->visible = (bool) $visible;
+
+        return $this;
+    }
+
     protected function redirectNow($url)
     {
         $response = Icinga::app()->getFrontController()->getResponse();
@@ -292,11 +323,12 @@ class FilterEditor extends AbstractWidget
                 if ($request->get('cancel') === 'Cancel') {
                     $this->redirectNow($this->preservedUrl()->without('modifyFilter'));
                 }
-
-                $filter = $this->applyChanges($request->getPost());
-                $url = $this->url()->setQueryString($filter->toQueryString())->addParams($preserve);
-                $url->getParams()->add('modifyFilter');
-                $this->redirectNow($url);
+                if ($request->get('formUID') === 'FilterEditor') {
+                    $filter = $this->applyChanges($request->getPost());
+                    $url = $this->url()->setQueryString($filter->toQueryString())->addParams($preserve);
+                    $url->getParams()->add('modifyFilter');
+                    $this->redirectNow($url);
+                }
             }
             $this->url()->getParams()->add('modifyFilter');
         }
@@ -703,8 +735,10 @@ class FilterEditor extends AbstractWidget
 
     public function renderSearch()
     {
-        $html = ' <form method="post" class="search inline dontprint" action="'
-              . $this->preservedUrl()
+        $preservedUrl = $this->preservedUrl();
+
+        $html = ' <form method="post" class="search inline" action="'
+              . $preservedUrl
               . '"><input type="text" name="q" style="width: 8em" class="search" value="" placeholder="'
               . t('Search...')
               . '" /></form>';
@@ -714,12 +748,13 @@ class FilterEditor extends AbstractWidget
         } else {
             $title = t('Modify this filter');
             if (! $this->filter->isEmpty()) {
-                $title .= ': ' . $this->filter;
+                $title .= ': ' . $this->view()->escape($this->filter);
             }
         }
+
         return $html
             . '<a href="'
-            . $this->preservedUrl()->with('modifyFilter', true)
+            . $preservedUrl->with('modifyFilter', ! $preservedUrl->getParam('modifyFilter'))
             . '" aria-label="'
             . $title
             . '" title="'
@@ -731,8 +766,11 @@ class FilterEditor extends AbstractWidget
 
     public function render()
     {
+        if (! $this->visible) {
+            return '';
+        }
         if (! $this->preservedUrl()->getParam('modifyFilter')) {
-            return '<div class="filter">' . $this->renderSearch() . $this->shorten($this->filter, 50) . '</div>';
+            return '<div class="filter">' . $this->renderSearch() . $this->view()->escape($this->shorten($this->filter, 50)) . '</div>';
         }
         return  '<div class="filter">'
             . $this->renderSearch()
@@ -746,6 +784,7 @@ class FilterEditor extends AbstractWidget
             . '<input type="submit" name="submit" value="Apply" />'
             . '<input type="submit" name="cancel" value="Cancel" />'
             . '</div>'
+            . '<input type="hidden" name="formUID" value="FilterEditor">'
             . '</form>'
             . '</div>';
     }
