@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Module\Monitoring\Controllers;
 
@@ -39,10 +39,18 @@ class ListController extends Controller
     }
 
     /**
-     * Display host list
+     * List hosts
      */
     public function hostsAction()
     {
+        $this->addTitleTab(
+            'hosts',
+            $this->translate('Hosts'),
+            $this->translate('List hosts')
+        );
+
+        $this->setAutorefreshInterval(10);
+
         // Handle soft and hard states
         if (strtolower($this->params->shift('stateType', 'soft')) === 'hard') {
             $stateColumn = 'host_hard_state';
@@ -51,9 +59,8 @@ class ListController extends Controller
             $stateColumn = 'host_state';
             $stateChangeColumn = 'host_last_state_change';
         }
-        $this->addTitleTab('hosts', $this->translate('Hosts'), $this->translate('List hosts'));
-        $this->setAutorefreshInterval(10);
-        $query = $this->backend->select()->from('hoststatus', array_merge(array(
+
+        $hosts = $this->backend->select()->from('hoststatus', array_merge(array(
             'host_icon_image',
             'host_icon_image_alt',
             'host_name',
@@ -71,9 +78,20 @@ class ListController extends Controller
             'host_active_checks_enabled',
             'host_passive_checks_enabled'
         ), $this->addColumns()));
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
-        $this->view->hosts = $query;
+        $this->applyRestriction('monitoring/filter/objects', $hosts);
+        $this->filterQuery($hosts);
+
+        $this->setupPaginationControl($hosts);
+        $this->setupLimitControl();
+        $this->setupSortControl(array(
+            'host_severity'             => $this->translate('Severity'),
+            'host_state'                => $this->translate('Current State'),
+            'host_display_name'         => $this->translate('Hostname'),
+            'host_address'              => $this->translate('Address'),
+            'host_last_check'           => $this->translate('Last Check'),
+            'host_last_state_change'    => $this->translate('Last State Change')
+        ), $hosts);
+
         $stats = $this->backend->select()->from('hoststatussummary', array(
             'hosts_total',
             'hosts_up',
@@ -86,27 +104,26 @@ class ListController extends Controller
             'hosts_pending',
         ));
         $this->applyRestriction('monitoring/filter/objects', $stats);
-        $this->view->stats = $stats;
-        $this->setupLimitControl();
-        $this->setupPaginationControl($this->view->hosts);
-        $this->setupSortControl(array(
-            'host_severity'     => $this->translate('Severity'),
-            'host_state'        => $this->translate('Current State'),
-            'host_display_name' => $this->translate('Hostname'),
-            'host_address'      => $this->translate('Address'),
-            'host_last_check'   => $this->translate('Last Check')
-        ), $query);
 
-        $summary = $query->getQuery()->queryServiceProblemSummary();
+        $summary = $hosts->getQuery()->queryServiceProblemSummary();
         $this->applyRestriction('monitoring/filter/objects', $summary);
+
+        $this->view->hosts = $hosts;
+        $this->view->stats = $stats;
         $this->view->summary = $summary->fetchPairs();
     }
 
     /**
-     * Display service list
+     * List services
      */
     public function servicesAction()
     {
+        $this->addTitleTab(
+            'services',
+            $this->translate('Services'),
+            $this->translate('List services')
+        );
+
         // Handle soft and hard states
         if (strtolower($this->params->shift('stateType', 'soft')) === 'hard') {
             $stateColumn = 'service_hard_state';
@@ -116,14 +133,9 @@ class ListController extends Controller
             $stateChangeColumn = 'service_last_state_change';
         }
 
-        $this->addTitleTab('services', $this->translate('Services'), $this->translate('List services'));
-        $this->view->showHost = true;
-        if (strpos($this->params->get('host_name', '*'), '*') === false) {
-            $this->view->showHost = false;
-        }
         $this->setAutorefreshInterval(10);
 
-        $columns = array_merge(array(
+        $services = $this->backend->select()->from('servicestatus', array_merge(array(
             'host_name',
             'host_display_name',
             'host_state',
@@ -146,25 +158,24 @@ class ListController extends Controller
             'service_notifications_enabled',
             'service_active_checks_enabled',
             'service_passive_checks_enabled'
-        ), $this->addColumns());
-        $query = $this->backend->select()->from('servicestatus', $columns);
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
-        $this->view->services = $query;
+        ), $this->addColumns()));
+        $this->applyRestriction('monitoring/filter/objects', $services);
+        $this->filterQuery($services);
 
+        $this->setupPaginationControl($services);
         $this->setupLimitControl();
-        $this->setupPaginationControl($this->view->services);
         $this->setupSortControl(array(
-            'service_severity'      => $this->translate('Service Severity'),
-            'service_state'         => $this->translate('Current Service State'),
-            'service_display_name'  => $this->translate('Service Name'),
-            'service_last_check'    => $this->translate('Last Service Check'),
-            'host_severity'         => $this->translate('Host Severity'),
-            'host_state'            => $this->translate('Current Host State'),
-            'host_display_name'     => $this->translate('Hostname'),
-            'host_address'          => $this->translate('Host Address'),
-            'host_last_check'       => $this->translate('Last Host Check')
-        ), $query);
+            'service_severity'          => $this->translate('Service Severity'),
+            'service_state'             => $this->translate('Current Service State'),
+            'service_display_name'      => $this->translate('Service Name'),
+            'service_last_check'        => $this->translate('Last Service Check'),
+            'service_last_state_change' => $this->translate('Last State Change'),
+            'host_severity'             => $this->translate('Host Severity'),
+            'host_state'                => $this->translate('Current Host State'),
+            'host_display_name'         => $this->translate('Hostname'),
+            'host_address'              => $this->translate('Host Address'),
+            'host_last_check'           => $this->translate('Last Host Check')
+        ), $services);
 
         $stats = $this->backend->select()->from('servicestatussummary', array(
             'services_critical',
@@ -181,18 +192,30 @@ class ListController extends Controller
             'services_warning_unhandled'
         ));
         $this->applyRestriction('monitoring/filter/objects', $stats);
+
+        $this->view->services = $services;
         $this->view->stats = $stats;
+        if (strpos($this->params->get('host_name', '*'), '*') === false) {
+            $this->view->showHost = false;
+        } else {
+            $this->view->showHost = true;
+        }
     }
 
     /**
-     * Fetch the current downtimes and put them into the view property `downtimes`
+     * List downtimes
      */
     public function downtimesAction()
     {
-        $this->addTitleTab('downtimes', $this->translate('Downtimes'), $this->translate('List downtimes'));
+        $this->addTitleTab(
+            'downtimes',
+            $this->translate('Downtimes'),
+            $this->translate('List downtimes')
+        );
+
         $this->setAutorefreshInterval(12);
 
-        $query = $this->backend->select()->from('downtime', array(
+        $downtimes = $this->backend->select()->from('downtime', array(
             'id'              => 'downtime_internal_id',
             'objecttype'      => 'object_type',
             'comment'         => 'downtime_comment',
@@ -206,6 +229,7 @@ class ListController extends Controller
             'is_fixed'        => 'downtime_is_fixed',
             'is_in_effect'    => 'downtime_is_in_effect',
             'entry_time'      => 'downtime_entry_time',
+            'name'            => 'downtime_name',
             'host_state',
             'service_state',
             'host_name',
@@ -213,13 +237,11 @@ class ListController extends Controller
             'host_display_name',
             'service_display_name'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
-
-        $this->view->downtimes = $query;
+        $this->applyRestriction('monitoring/filter/objects', $downtimes);
+        $this->filterQuery($downtimes);
 
+        $this->setupPaginationControl($downtimes);
         $this->setupLimitControl();
-        $this->setupPaginationControl($this->view->downtimes);
         $this->setupSortControl(array(
             'downtime_is_in_effect'     => $this->translate('Is In Effect'),
             'host_display_name'         => $this->translate('Host'),
@@ -231,7 +253,9 @@ class ListController extends Controller
             'downtime_scheduled_start'  => $this->translate('Scheduled Start'),
             'downtime_scheduled_end'    => $this->translate('Scheduled End'),
             'downtime_duration'         => $this->translate('Duration')
-        ), $query);
+        ), $downtimes);
+
+        $this->view->downtimes = $downtimes;
 
         if ($this->Auth()->hasPermission('monitoring/command/downtime/delete')) {
             $this->view->delDowntimeForm = new DeleteDowntimeCommandForm();
@@ -240,7 +264,7 @@ class ListController extends Controller
     }
 
     /**
-     * Display notification overview
+     * List notifications
      */
     public function notificationsAction()
     {
@@ -249,34 +273,43 @@ class ListController extends Controller
             $this->translate('Notifications'),
             $this->translate('List notifications')
         );
+
         $this->setAutorefreshInterval(15);
 
-        $query = $this->backend->select()->from('notification', array(
-            'host_name',
-            'service_description',
-            'notification_output',
-            'notification_contact_name',
-            'notification_start_time',
-            'notification_state',
+        $notifications = $this->backend->select()->from('notification', array(
             'host_display_name',
+            'host_name',
+            'notification_contact_name',
+            'notification_output',
+            'notification_state',
+            'notification_timestamp',
+            'service_description',
             'service_display_name'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
-        $this->view->notifications = $query;
+        $this->applyRestriction('monitoring/filter/objects', $notifications);
+        $this->filterQuery($notifications);
 
+        $this->setupPaginationControl($notifications);
         $this->setupLimitControl();
-        $this->setupPaginationControl($this->view->notifications);
         $this->setupSortControl(array(
-            'notification_start_time' => $this->translate('Notification Start')
-        ), $query);
+            'notification_timestamp' => $this->translate('Notification Start')
+        ), $notifications);
+
+        $this->view->notifications = $notifications;
     }
 
+    /**
+     * List contacts
+     */
     public function contactsAction()
     {
-        $this->addTitleTab('contacts', $this->translate('Contacts'), $this->translate('List contacts'));
+        $this->addTitleTab(
+            'contacts',
+            $this->translate('Contacts'),
+            $this->translate('List contacts')
+        );
 
-        $query = $this->backend->select()->from('contact', array(
+        $contacts = $this->backend->select()->from('contact', array(
             'contact_name',
             'contact_alias',
             'contact_email',
@@ -284,20 +317,19 @@ class ListController extends Controller
             'contact_notify_service_timeperiod',
             'contact_notify_host_timeperiod'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
-        $this->view->contacts = $query;
+        $this->applyRestriction('monitoring/filter/objects', $contacts);
+        $this->filterQuery($contacts);
 
+        $this->setupPaginationControl($contacts);
         $this->setupLimitControl();
-        $this->setupPaginationControl($this->view->contacts);
         $this->setupSortControl(array(
-            'contact_name' => $this->translate('Name'),
+            'contact_name'  => $this->translate('Name'),
             'contact_alias' => $this->translate('Alias'),
             'contact_email' => $this->translate('Email'),
-            'contact_pager' => $this->translate('Pager Address / Number'),
-            'contact_notify_service_timeperiod' => $this->translate('Service Notification Timeperiod'),
-            'contact_notify_host_timeperiod' => $this->translate('Host Notification Timeperiod')
-        ), $query);
+            'contact_pager' => $this->translate('Pager Address / Number')
+        ), $contacts);
+
+        $this->view->contacts = $contacts;
     }
 
     public function eventgridAction()
@@ -340,6 +372,9 @@ class ListController extends Controller
         $this->view->orientation = $orientation;
     }
 
+    /**
+     * List contact groups
+     */
     public function contactgroupsAction()
     {
         $this->addTitleTab(
@@ -348,47 +383,38 @@ class ListController extends Controller
             $this->translate('List contact groups')
         );
 
-        $query = $this->backend->select()->from('contactgroup', array(
+        $contactGroups = $this->backend->select()->from('contactgroup', array(
             'contactgroup_name',
             'contactgroup_alias',
-            'contact_name',
-            'contact_alias',
-            'contact_email',
-            'contact_pager'
+            'contact_count'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
+        $this->applyRestriction('monitoring/filter/objects', $contactGroups);
+        $this->filterQuery($contactGroups);
 
+        $this->setupPaginationControl($contactGroups);
+        $this->setupLimitControl();
         $this->setupSortControl(array(
             'contactgroup_name'     => $this->translate('Contactgroup Name'),
             'contactgroup_alias'    => $this->translate('Contactgroup Alias')
-        ), $query);
+        ), $contactGroups);
 
-        // Fetch and prepare all contact groups:
-        $contactgroups = $query->getQuery()->fetchAll();
-        $groupData = array();
-        foreach ($contactgroups as $c) {
-            if (!array_key_exists($c->contactgroup_name, $groupData)) {
-                $groupData[$c->contactgroup_name] = array(
-                    'alias'     => $c->contactgroup_alias,
-                    'contacts'  => array()
-                );
-            }
-            if (isset ($c->contact_name)) {
-                $groupData[$c->contactgroup_name]['contacts'][] = $c;
-            }
-        }
-
-        // TODO: Find a better naming
-        $this->view->groupData = $groupData;
+        $this->view->contactGroups = $contactGroups;
     }
 
+    /**
+     * List all comments
+     */
     public function commentsAction()
     {
-        $this->addTitleTab('comments', $this->translate('Comments'), $this->translate('List comments'));
+        $this->addTitleTab(
+            'comments',
+            $this->translate('Comments'),
+            $this->translate('List comments')
+        );
+
         $this->setAutorefreshInterval(12);
 
-        $query = $this->backend->select()->from('comment', array(
+        $comments = $this->backend->select()->from('comment', array(
             'id'         => 'comment_internal_id',
             'objecttype' => 'object_type',
             'comment'    => 'comment_data',
@@ -397,17 +423,17 @@ class ListController extends Controller
             'type'       => 'comment_type',
             'persistent' => 'comment_is_persistent',
             'expiration' => 'comment_expiration',
+            'name'       => 'comment_name',
             'host_name',
             'service_description',
             'host_display_name',
             'service_display_name'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
-        $this->view->comments = $query;
+        $this->applyRestriction('monitoring/filter/objects', $comments);
+        $this->filterQuery($comments);
 
+        $this->setupPaginationControl($comments);
         $this->setupLimitControl();
-        $this->setupPaginationControl($this->view->comments);
         $this->setupSortControl(
             array(
                 'comment_timestamp'     => $this->translate('Comment Timestamp'),
@@ -416,15 +442,20 @@ class ListController extends Controller
                 'comment_type'          => $this->translate('Comment Type'),
                 'comment_expiration'    => $this->translate('Expiration')
             ),
-            $query
+            $comments
         );
 
+        $this->view->comments = $comments;
+
         if ($this->Auth()->hasPermission('monitoring/command/comment/delete')) {
             $this->view->delCommentForm = new DeleteCommentCommandForm();
             $this->view->delCommentForm->handleRequest();
         }
     }
 
+    /**
+     * List service groups
+     */
     public function servicegroupsAction()
     {
         $this->addTitleTab(
@@ -432,9 +463,10 @@ class ListController extends Controller
             $this->translate('Service Groups'),
             $this->translate('List service groups')
         );
+
         $this->setAutorefreshInterval(12);
 
-        $query = $this->backend->select()->from('servicegroupsummary', array(
+        $serviceGroups = $this->backend->select()->from('servicegroupsummary', array(
             'servicegroup_alias',
             'servicegroup_name',
             'services_critical_handled',
@@ -447,25 +479,34 @@ class ListController extends Controller
             'services_warning_handled',
             'services_warning_unhandled'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
-        $this->view->servicegroups = $query;
+        $this->applyRestriction('monitoring/filter/objects', $serviceGroups);
+        $this->filterQuery($serviceGroups);
 
+        $this->setupPaginationControl($serviceGroups);
         $this->setupLimitControl();
-        $this->setupPaginationControl($this->view->servicegroups);
         $this->setupSortControl(array(
             'services_severity'     => $this->translate('Severity'),
             'servicegroup_alias'    => $this->translate('Service Group Name'),
             'services_total'        => $this->translate('Total Services')
-        ), $query);
+        ), $serviceGroups);
+
+        $this->view->serviceGroups = $serviceGroups;
     }
 
+    /**
+     * List host groups
+     */
     public function hostgroupsAction()
     {
-        $this->addTitleTab('hostgroups', $this->translate('Host Groups'), $this->translate('List host groups'));
+        $this->addTitleTab(
+            'hostgroups',
+            $this->translate('Host Groups'),
+            $this->translate('List host groups')
+        );
+
         $this->setAutorefreshInterval(12);
 
-        $query = $this->backend->select()->from('hostgroupsummary', array(
+        $hostGroups = $this->backend->select()->from('hostgroupsummary', array(
             'hostgroup_alias',
             'hostgroup_name',
             'hosts_down_handled',
@@ -485,18 +526,19 @@ class ListController extends Controller
             'services_warning_handled',
             'services_warning_unhandled'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
-        $this->view->hostgroups = $query;
+        $this->applyRestriction('monitoring/filter/objects', $hostGroups);
+        $this->filterQuery($hostGroups);
 
+        $this->setupPaginationControl($hostGroups);
         $this->setupLimitControl();
-        $this->setupPaginationControl($this->view->hostgroups);
         $this->setupSortControl(array(
             'hosts_severity'    => $this->translate('Severity'),
             'hostgroup_alias'   => $this->translate('Host Group Name'),
             'hosts_total'       => $this->translate('Total Hosts'),
             'services_total'    => $this->translate('Total Services')
-        ), $query);
+        ), $hostGroups);
+
+        $this->view->hostGroups = $hostGroups;
     }
 
     public function eventhistoryAction()
