@@ -211,16 +211,16 @@
          * Our window got resized, let's fix our UI
          */
         onWindowResize: function (event) {
-            var self = event.data.self;
+            var _this = event.data.self;
 
-            if (self.layoutHasBeenChanged()) {
-                self.icinga.logger.info(
+            if (_this.layoutHasBeenChanged()) {
+                _this.icinga.logger.info(
                     'Layout change detected, switching to',
-                    self.currentLayout
+                    _this.currentLayout
                 );
             }
-            self.fixControls();
-            self.refreshDebug();
+            _this.fixControls();
+            _this.refreshDebug();
         },
 
         /**
@@ -273,6 +273,7 @@
             $('#layout').removeClass('twocols');
             this.closeContainer($('#col2'));
             // one-column layouts never have any selection active
+            $('#col1').removeData('icinga-actiontable-former-href');
             this.icinga.behaviors.actiontable.clearAll();
         },
 
@@ -458,7 +459,6 @@
          * Initialize all TriStateCheckboxes in the given html
          */
         initializeTriStates: function ($html) {
-            var self = this;
             $('div.tristate', $html).each(function(index, item) {
                 var $target  = $(item);
 
@@ -579,9 +579,7 @@
                 var $search = $('#search');
                 var $sidebar = $('#sidebar');
 
-                $header.css({
-                    height: 'auto'
-                });
+                $header.css({ height: 'auto'});
 
                 if ($layout.hasClass('minimal-layout')) {
                     if (! this.mobileMenu && $sidebar.length) {
@@ -658,14 +656,21 @@
             $container.find('.controls').each(function() {
                 var $controls = $(this);
                 var $fakeControls = $controls.next('.fake-controls');
-
                 $controls.css({
                     top: $container.offset().top,
                     width: $fakeControls.outerWidth()
                 });
-
                 $fakeControls.height($controls.height());
             });
+
+            var $statusBar = $container.children('.monitoring-statusbar');
+            if ($statusBar.length) {
+                $statusBar.css({
+                    left: $container.offset().left,
+                    width: $container.width()
+                });
+                $statusBar.prev('.monitoring-statusbar-ghost').height($statusBar.outerHeight(true));
+            }
         },
 
         toggleFullscreen: function () {
